searchData={"content_type":"text/markdown","items":[{"doc":"ElixirMpesa is an Elixir library for integrating with Vodacom M-Pesa OpenAPI.\n\nThis library provides functions to interact with various M-Pesa services including:\n- Session key generation and management\n- Customer to Business (C2B) payments\n- Business to Customer (B2C) payments\n- Business to Business (B2B) payments\n- Transaction status queries\n- Direct debit operations\n- Beneficiary name queries","ref":"ElixirMpesa.html","title":"ElixirMpesa","type":"module"},{"doc":"Add the following to your `config/config.exs`:\n\n```elixir\nconfig :elixir_mpesa,\n  api_type: \"sandbox\", # or \"openapi\" for production\n  input_currency: \"LSL\", # Currency code (e.g., \"LSL\" for Lesotho Loti)\n  input_country: \"LES\", # Country code\n  url_context: \"vodacomLES\", # API context (country-specific)\n  api_key: \"your_api_key_here\", # Your M-Pesa API key\n  public_key: \"your_public_key_here\" # Your M-Pesa public key\n```","ref":"ElixirMpesa.html#module-configuration","title":"Configuration - ElixirMpesa","type":"module"},{"doc":"```elixir\n# Encrypt your API key\n{:ok, encrypted_api_key} = ElixirMpesa.encrypt_api_key()\n\n# Generate a session key\n{:ok, session_data} = ElixirMpesa.generate_session_key(encrypted_api_key)\nsession_key = session_data[\"output_SessionID\"]\n\n# Encrypt the session key for use in subsequent requests\n{:ok, encrypted_session_key} = ElixirMpesa.encrypt_session_key(session_key)\n\n# Make a C2B payment\npayment_data = %{\n  \"input_Amount\" => 10.0,\n  \"input_Country\" => \"LES\",\n  \"input_Currency\" => \"LSL\",\n  \"input_CustomerMSISDN\" => \"26675000000\",\n  \"input_ServiceProviderCode\" => \"00000\",\n  \"input_ThirdPartyConversationID\" => \"asv02e5958774f7ba228d83d0d689761\",\n  \"input_TransactionReference\" => \"T12344C\",\n  \"input_PurchasedItemsDesc\" => \"Test purchase\"\n}\n\n{:ok, result} = ElixirMpesa.c2b_single_stage(payment_data, encrypted_session_key)\n```","ref":"ElixirMpesa.html#module-basic-usage","title":"Basic Usage - ElixirMpesa","type":"module"},{"doc":"Performs a Business to Business (B2B) single-stage payment.","ref":"ElixirMpesa.html#b2b_single_stage/3","title":"ElixirMpesa.b2b_single_stage/3","type":"function"},{"doc":"* `body` - Map containing the transaction details\n* `encrypted_session_key` - The encrypted session key\n* `options` - Configuration options","ref":"ElixirMpesa.html#b2b_single_stage/3-parameters","title":"Parameters - ElixirMpesa.b2b_single_stage/3","type":"function"},{"doc":"* `\"input_Amount\"` - The transaction amount\n* `\"input_Country\"` - The country code (e.g., \"LES\")\n* `\"input_Currency\"` - The currency code (e.g., \"LSL\")\n* `\"input_PrimaryPartyCode\"` - The primary party code (your business)\n* `\"input_ReceiverPartyCode\"` - The receiver party code (recipient business)\n* `\"input_ThirdPartyConversationID\"` - A unique ID for this transaction\n* `\"input_TransactionReference\"` - Your reference for this transaction\n* `\"input_PurchasedItemsDesc\"` - Description of the payment","ref":"ElixirMpesa.html#b2b_single_stage/3-body-parameters","title":"Body Parameters - ElixirMpesa.b2b_single_stage/3","type":"function"},{"doc":"iex> payment_data = %{\n    ...>   \"input_Amount\" => 1000.0,\n    ...>   \"input_Country\" => \"LES\",\n    ...>   \"input_Currency\" => \"LSL\",\n    ...>   \"input_PrimaryPartyCode\" => \"12345\",\n    ...>   \"input_ReceiverPartyCode\" => \"54321\",\n    ...>   \"input_ThirdPartyConversationID\" => \"asv02e5958774f7ba228d83d0d689761\",\n    ...>   \"input_TransactionReference\" => \"T12344C\",\n    ...>   \"input_PurchasedItemsDesc\" => \"Invoice payment\"\n    ...> }\n    iex> ElixirMpesa.b2b_single_stage(payment_data, encrypted_session_key)\n    {:ok, %{\"output_ResponseCode\" => \"INS-0\", \"output_ResponseDesc\" => \"Request processed successfully\", ...}}","ref":"ElixirMpesa.html#b2b_single_stage/3-examples","title":"Examples - ElixirMpesa.b2b_single_stage/3","type":"function"},{"doc":"Performs a Business to Customer (B2C) single-stage payment.","ref":"ElixirMpesa.html#b2c_single_stage/3","title":"ElixirMpesa.b2c_single_stage/3","type":"function"},{"doc":"* `body` - Map containing the transaction details\n* `encrypted_session_key` - The encrypted session key\n* `options` - Configuration options","ref":"ElixirMpesa.html#b2c_single_stage/3-parameters","title":"Parameters - ElixirMpesa.b2c_single_stage/3","type":"function"},{"doc":"* `\"input_Amount\"` - The transaction amount\n* `\"input_Country\"` - The country code (e.g., \"LES\")\n* `\"input_Currency\"` - The currency code (e.g., \"LSL\")\n* `\"input_CustomerMSISDN\"` - The recipient's phone number\n* `\"input_ServiceProviderCode\"` - The service provider code\n* `\"input_ThirdPartyConversationID\"` - A unique ID for this transaction\n* `\"input_TransactionReference\"` - Your reference for this transaction\n* `\"input_PaymentItemsDesc\"` - Description of the payment","ref":"ElixirMpesa.html#b2c_single_stage/3-body-parameters","title":"Body Parameters - ElixirMpesa.b2c_single_stage/3","type":"function"},{"doc":"iex> payment_data = %{\n    ...>   \"input_Amount\" => 10.0,\n    ...>   \"input_Country\" => \"LES\",\n    ...>   \"input_Currency\" => \"LSL\",\n    ...>   \"input_CustomerMSISDN\" => \"26675000000\",\n    ...>   \"input_ServiceProviderCode\" => \"00000\",\n    ...>   \"input_ThirdPartyConversationID\" => \"asv02e5958774f7ba228d83d0d689761\",\n    ...>   \"input_TransactionReference\" => \"T12344C\",\n    ...>   \"input_PaymentItemsDesc\" => \"Salary payment\"\n    ...> }\n    iex> ElixirMpesa.b2c_single_stage(payment_data, encrypted_session_key)\n    {:ok, %{\"output_ResponseCode\" => \"INS-0\", \"output_ResponseDesc\" => \"Request processed successfully\", ...}}","ref":"ElixirMpesa.html#b2c_single_stage/3-examples","title":"Examples - ElixirMpesa.b2c_single_stage/3","type":"function"},{"doc":"Performs a Customer to Business (C2B) single-stage payment.","ref":"ElixirMpesa.html#c2b_single_stage/3","title":"ElixirMpesa.c2b_single_stage/3","type":"function"},{"doc":"* `body` - Map containing the transaction details\n* `encrypted_session_key` - The encrypted session key\n* `options` - Configuration options","ref":"ElixirMpesa.html#c2b_single_stage/3-parameters","title":"Parameters - ElixirMpesa.c2b_single_stage/3","type":"function"},{"doc":"* `\"input_Amount\"` - The transaction amount\n* `\"input_Country\"` - The country code (e.g., \"LES\")\n* `\"input_Currency\"` - The currency code (e.g., \"LSL\")\n* `\"input_CustomerMSISDN\"` - The customer's phone number\n* `\"input_ServiceProviderCode\"` - The service provider code\n* `\"input_ThirdPartyConversationID\"` - A unique ID for this transaction\n* `\"input_TransactionReference\"` - Your reference for this transaction\n* `\"input_PurchasedItemsDesc\"` - Description of the purchase","ref":"ElixirMpesa.html#c2b_single_stage/3-body-parameters","title":"Body Parameters - ElixirMpesa.c2b_single_stage/3","type":"function"},{"doc":"iex> payment_data = %{\n    ...>   \"input_Amount\" => 10.0,\n    ...>   \"input_Country\" => \"LES\",\n    ...>   \"input_Currency\" => \"LSL\",\n    ...>   \"input_CustomerMSISDN\" => \"26675000000\",\n    ...>   \"input_ServiceProviderCode\" => \"00000\",\n    ...>   \"input_ThirdPartyConversationID\" => \"asv02e5958774f7ba228d83d0d689761\",\n    ...>   \"input_TransactionReference\" => \"T12344C\",\n    ...>   \"input_PurchasedItemsDesc\" => \"Test purchase\"\n    ...> }\n    iex> ElixirMpesa.c2b_single_stage(payment_data, encrypted_session_key)\n    {:ok, %{\"output_ResponseCode\" => \"INS-0\", \"output_ResponseDesc\" => \"Request processed successfully\", ...}}","ref":"ElixirMpesa.html#c2b_single_stage/3-examples","title":"Examples - ElixirMpesa.c2b_single_stage/3","type":"function"},{"doc":"Cancels a direct debit mandate.","ref":"ElixirMpesa.html#direct_debit_cancel/3","title":"ElixirMpesa.direct_debit_cancel/3","type":"function"},{"doc":"* `body` - Map containing the cancellation details\n* `encrypted_session_key` - The encrypted session key\n* `options` - Configuration options","ref":"ElixirMpesa.html#direct_debit_cancel/3-parameters","title":"Parameters - ElixirMpesa.direct_debit_cancel/3","type":"function"},{"doc":"* `\"input_CustomerMSISDN\"` - The customer's phone number\n* `\"input_Country\"` - The country code (e.g., \"LES\")\n* `\"input_ServiceProviderCode\"` - The service provider code\n* `\"input_ThirdPartyConversationID\"` - A unique ID for this cancellation\n* `\"input_ThirdPartyReference\"` - The original mandate reference","ref":"ElixirMpesa.html#direct_debit_cancel/3-body-parameters","title":"Body Parameters - ElixirMpesa.direct_debit_cancel/3","type":"function"},{"doc":"iex> cancel_data = %{\n    ...>   \"input_CustomerMSISDN\" => \"26675000000\",\n    ...>   \"input_Country\" => \"LES\",\n    ...>   \"input_ServiceProviderCode\" => \"00000\",\n    ...>   \"input_ThirdPartyConversationID\" => \"asv02e5958774f7ba228d83d0d689761\",\n    ...>   \"input_ThirdPartyReference\" => \"3333\"\n    ...> }\n    iex> ElixirMpesa.direct_debit_cancel(cancel_data, encrypted_session_key)\n    {:ok, %{\"output_ResponseCode\" => \"INS-0\", \"output_ResponseDesc\" => \"Request processed successfully\", ...}}","ref":"ElixirMpesa.html#direct_debit_cancel/3-examples","title":"Examples - ElixirMpesa.direct_debit_cancel/3","type":"function"},{"doc":"Creates a direct debit mandate.","ref":"ElixirMpesa.html#direct_debit_creation/3","title":"ElixirMpesa.direct_debit_creation/3","type":"function"},{"doc":"* `body` - Map containing the direct debit details\n* `encrypted_session_key` - The encrypted session key\n* `options` - Configuration options","ref":"ElixirMpesa.html#direct_debit_creation/3-parameters","title":"Parameters - ElixirMpesa.direct_debit_creation/3","type":"function"},{"doc":"* `\"input_AgreedTC\"` - Whether the customer has agreed to terms and conditions (boolean)\n* `\"input_Country\"` - The country code (e.g., \"LES\")\n* `\"input_CustomerMSISDN\"` - The customer's phone number\n* `\"input_ServiceProviderCode\"` - The service provider code\n* `\"input_ThirdPartyConversationID\"` - A unique ID for this transaction\n* `\"input_ThirdPartyReference\"` - Your reference for this mandate","ref":"ElixirMpesa.html#direct_debit_creation/3-body-parameters","title":"Body Parameters - ElixirMpesa.direct_debit_creation/3","type":"function"},{"doc":"iex> direct_debit_data = %{\n    ...>   \"input_AgreedTC\" => true,\n    ...>   \"input_Country\" => \"LES\",\n    ...>   \"input_CustomerMSISDN\" => \"26675000000\",\n    ...>   \"input_ServiceProviderCode\" => \"00000\",\n    ...>   \"input_ThirdPartyConversationID\" => \"asv02e5958774f7ba228d83d0d689761\",\n    ...>   \"input_ThirdPartyReference\" => \"3333\"\n    ...> }\n    iex> ElixirMpesa.direct_debit_creation(direct_debit_data, encrypted_session_key)\n    {:ok, %{\"output_ResponseCode\" => \"INS-0\", \"output_ResponseDesc\" => \"Request processed successfully\", ...}}","ref":"ElixirMpesa.html#direct_debit_creation/3-examples","title":"Examples - ElixirMpesa.direct_debit_creation/3","type":"function"},{"doc":"Processes a direct debit payment.","ref":"ElixirMpesa.html#direct_debit_payment/3","title":"ElixirMpesa.direct_debit_payment/3","type":"function"},{"doc":"* `body` - Map containing the payment details\n* `encrypted_session_key` - The encrypted session key\n* `options` - Configuration options","ref":"ElixirMpesa.html#direct_debit_payment/3-parameters","title":"Parameters - ElixirMpesa.direct_debit_payment/3","type":"function"},{"doc":"* `\"input_Amount\"` - The transaction amount\n* `\"input_Country\"` - The country code (e.g., \"LES\")\n* `\"input_Currency\"` - The currency code (e.g., \"LSL\")\n* `\"input_CustomerMSISDN\"` - The customer's phone number\n* `\"input_ServiceProviderCode\"` - The service provider code\n* `\"input_ThirdPartyConversationID\"` - A unique ID for this transaction\n* `\"input_ThirdPartyReference\"` - Your reference for this payment","ref":"ElixirMpesa.html#direct_debit_payment/3-body-parameters","title":"Body Parameters - ElixirMpesa.direct_debit_payment/3","type":"function"},{"doc":"iex> payment_data = %{\n    ...>   \"input_Amount\" => 10.0,\n    ...>   \"input_Country\" => \"LES\",\n    ...>   \"input_Currency\" => \"LSL\",\n    ...>   \"input_CustomerMSISDN\" => \"26675000000\",\n    ...>   \"input_ServiceProviderCode\" => \"00000\",\n    ...>   \"input_ThirdPartyConversationID\" => \"asv02e5958774f7ba228d83d0d689761\",\n    ...>   \"input_ThirdPartyReference\" => \"3333\"\n    ...> }\n    iex> ElixirMpesa.direct_debit_payment(payment_data, encrypted_session_key)\n    {:ok, %{\"output_ResponseCode\" => \"INS-0\", \"output_ResponseDesc\" => \"Request processed successfully\", ...}}","ref":"ElixirMpesa.html#direct_debit_payment/3-examples","title":"Examples - ElixirMpesa.direct_debit_payment/3","type":"function"},{"doc":"Encrypts the API key using the configured public key.","ref":"ElixirMpesa.html#encrypt_api_key/1","title":"ElixirMpesa.encrypt_api_key/1","type":"function"},{"doc":"* `:public_key` - Override the configured public key\n* `:api_key` - Override the configured API key\n* `:api_type` - Override the configured API type (\"sandbox\" or \"openapi\")\n* `:url_context` - Override the configured URL context","ref":"ElixirMpesa.html#encrypt_api_key/1-options","title":"Options - ElixirMpesa.encrypt_api_key/1","type":"function"},{"doc":"iex> ElixirMpesa.encrypt_api_key()\n    {:ok, \"encrypted_api_key_string\"}\n\n    iex> ElixirMpesa.encrypt_api_key([public_key: \"custom_public_key\", api_key: \"custom_api_key\"])\n    {:ok, \"encrypted_api_key_string\"}","ref":"ElixirMpesa.html#encrypt_api_key/1-examples","title":"Examples - ElixirMpesa.encrypt_api_key/1","type":"function"},{"doc":"Encrypts a session key using the configured public key.","ref":"ElixirMpesa.html#encrypt_session_key/2","title":"ElixirMpesa.encrypt_session_key/2","type":"function"},{"doc":"* `session_key` - The session key to encrypt\n* `options` - Configuration options (see below)","ref":"ElixirMpesa.html#encrypt_session_key/2-parameters","title":"Parameters - ElixirMpesa.encrypt_session_key/2","type":"function"},{"doc":"* `:public_key` - Override the configured public key","ref":"ElixirMpesa.html#encrypt_session_key/2-options","title":"Options - ElixirMpesa.encrypt_session_key/2","type":"function"},{"doc":"iex> {:ok, session_result} = ElixirMpesa.generate_session_key()\n    iex> session_key = session_result[\"output_SessionID\"]\n    iex> ElixirMpesa.encrypt_session_key(session_key)\n    {:ok, \"encrypted_session_key_string\"}","ref":"ElixirMpesa.html#encrypt_session_key/2-examples","title":"Examples - ElixirMpesa.encrypt_session_key/2","type":"function"},{"doc":"Generates a session key using the encrypted API key.","ref":"ElixirMpesa.html#generate_session_key/2","title":"ElixirMpesa.generate_session_key/2","type":"function"},{"doc":"* `encrypt_api_key` - The encrypted API key (optional)\n* `options` - Configuration options (see below)","ref":"ElixirMpesa.html#generate_session_key/2-parameters","title":"Parameters - ElixirMpesa.generate_session_key/2","type":"function"},{"doc":"* `:api_type` - Override the configured API type (\"sandbox\" or \"openapi\")\n* `:url_context` - Override the configured URL context","ref":"ElixirMpesa.html#generate_session_key/2-options","title":"Options - ElixirMpesa.generate_session_key/2","type":"function"},{"doc":"iex> {:ok, encrypted_api_key} = ElixirMpesa.encrypt_api_key()\n    iex> ElixirMpesa.generate_session_key(encrypted_api_key)\n    {:ok, %{\"output_ResponseCode\" => \"INS-0\", \"output_ResponseDesc\" => \"Request processed successfully\", \"output_SessionID\" => \"session_key_string\"}}\n\n    iex> ElixirMpesa.generate_session_key()  # Uses the default configured API key\n    {:ok, %{\"output_ResponseCode\" => \"INS-0\", \"output_ResponseDesc\" => \"Request processed successfully\", \"output_SessionID\" => \"session_key_string\"}}","ref":"ElixirMpesa.html#generate_session_key/2-examples","title":"Examples - ElixirMpesa.generate_session_key/2","type":"function"},{"doc":"Queries a beneficiary's name based on their mobile number.","ref":"ElixirMpesa.html#query_beneficiary_name/3","title":"ElixirMpesa.query_beneficiary_name/3","type":"function"},{"doc":"* `body` - Map containing the query details\n* `encrypted_session_key` - The encrypted session key\n* `options` - Configuration options","ref":"ElixirMpesa.html#query_beneficiary_name/3-parameters","title":"Parameters - ElixirMpesa.query_beneficiary_name/3","type":"function"},{"doc":"* `\"input_CustomerMSISDN\"` - The customer's phone number\n* `\"input_Country\"` - The country code (e.g., \"LES\")\n* `\"input_ServiceProviderCode\"` - The service provider code\n* `\"input_ThirdPartyConversationID\"` - A unique ID for this query","ref":"ElixirMpesa.html#query_beneficiary_name/3-body-parameters","title":"Body Parameters - ElixirMpesa.query_beneficiary_name/3","type":"function"},{"doc":"iex> query_data = %{\n    ...>   \"input_CustomerMSISDN\" => \"26675000000\",\n    ...>   \"input_Country\" => \"LES\",\n    ...>   \"input_ServiceProviderCode\" => \"00000\",\n    ...>   \"input_ThirdPartyConversationID\" => \"asv02e5958774f7ba228d83d0d689761\"\n    ...> }\n    iex> ElixirMpesa.query_beneficiary_name(query_data, encrypted_session_key)\n    {:ok, %{\"output_ResponseCode\" => \"INS-0\", \"output_ResponseDesc\" => \"Request processed successfully\", \"output_CustomerFirstName\" => \"John\", \"output_CustomerLastName\" => \"Doe\"}}","ref":"ElixirMpesa.html#query_beneficiary_name/3-examples","title":"Examples - ElixirMpesa.query_beneficiary_name/3","type":"function"},{"doc":"Queries the status of a direct debit mandate.","ref":"ElixirMpesa.html#query_direct_debit/3","title":"ElixirMpesa.query_direct_debit/3","type":"function"},{"doc":"* `body` - Map containing the query details\n* `encrypted_session_key` - The encrypted session key\n* `options` - Configuration options","ref":"ElixirMpesa.html#query_direct_debit/3-parameters","title":"Parameters - ElixirMpesa.query_direct_debit/3","type":"function"},{"doc":"* `\"input_CustomerMSISDN\"` - The customer's phone number\n* `\"input_Country\"` - The country code (e.g., \"LES\")\n* `\"input_ServiceProviderCode\"` - The service provider code\n* `\"input_ThirdPartyConversationID\"` - A unique ID for this query\n* `\"input_ThirdPartyReference\"` - The original mandate reference","ref":"ElixirMpesa.html#query_direct_debit/3-body-parameters","title":"Body Parameters - ElixirMpesa.query_direct_debit/3","type":"function"},{"doc":"iex> query_data = %{\n    ...>   \"input_CustomerMSISDN\" => \"26675000000\",\n    ...>   \"input_Country\" => \"LES\",\n    ...>   \"input_ServiceProviderCode\" => \"00000\",\n    ...>   \"input_ThirdPartyConversationID\" => \"asv02e5958774f7ba228d83d0d689761\",\n    ...>   \"input_ThirdPartyReference\" => \"3333\"\n    ...> }\n    iex> ElixirMpesa.query_direct_debit(query_data, encrypted_session_key)\n    {:ok, %{\"output_ResponseCode\" => \"INS-0\", \"output_ResponseDesc\" => \"Request processed successfully\", ...}}","ref":"ElixirMpesa.html#query_direct_debit/3-examples","title":"Examples - ElixirMpesa.query_direct_debit/3","type":"function"},{"doc":"Queries the status of a transaction.","ref":"ElixirMpesa.html#query_transaction_status/3","title":"ElixirMpesa.query_transaction_status/3","type":"function"},{"doc":"* `body` - Map containing the query details\n* `encrypted_session_key` - The encrypted session key\n* `options` - Configuration options","ref":"ElixirMpesa.html#query_transaction_status/3-parameters","title":"Parameters - ElixirMpesa.query_transaction_status/3","type":"function"},{"doc":"* `\"input_QueryReference\"` - The original transaction reference\n* `\"input_ServiceProviderCode\"` - The service provider code\n* `\"input_ThirdPartyConversationID\"` - A unique ID for this query\n* `\"input_Country\"` - The country code (e.g., \"LES\")","ref":"ElixirMpesa.html#query_transaction_status/3-body-parameters","title":"Body Parameters - ElixirMpesa.query_transaction_status/3","type":"function"},{"doc":"iex> query_data = %{\n    ...>   \"input_QueryReference\" => \"T12344C\",\n    ...>   \"input_ServiceProviderCode\" => \"00000\",\n    ...>   \"input_ThirdPartyConversationID\" => \"asv02e5958774f7ba228d83d0d689761\",\n    ...>   \"input_Country\" => \"LES\"\n    ...> }\n    iex> ElixirMpesa.query_transaction_status(query_data, encrypted_session_key)\n    {:ok, %{\"output_ResponseCode\" => \"INS-0\", \"output_ResponseDesc\" => \"Request processed successfully\", ...}}","ref":"ElixirMpesa.html#query_transaction_status/3-examples","title":"Examples - ElixirMpesa.query_transaction_status/3","type":"function"},{"doc":"Handles the session key generation and management for M-Pesa OpenAPI.\n\nBefore integrating with the M-Pesa OpenAPI solution, you must exchange your\nApplication Key for a Session Key. The API Key is created with the creation of a new application.\nThe Session Key acts as an access token that authorizes the rest of your REST API calls to the system.\nA valid Session Key is needed to transact on M-Pesa using OpenAPI.","ref":"ElixirMpesa.GenerateSessionKey.html","title":"ElixirMpesa.GenerateSessionKey","type":"module"},{"doc":"1. Encrypt API key using the public key provided by M-Pesa\n2. Send the encrypted API key to the Session API endpoint\n3. Receive a session key in response\n4. Encrypt the session key for use in subsequent API calls","ref":"ElixirMpesa.GenerateSessionKey.html#module-process-flow","title":"Process Flow - ElixirMpesa.GenerateSessionKey","type":"module"},{"doc":"# Encrypt the API key\n    {:ok, encrypted_api_key} = ElixirMpesa.GenerateSessionKey.encrypt_api_key()\n\n    # Generate a session ID using the encrypted API key\n    {:ok, session_data} = ElixirMpesa.GenerateSessionKey.generate_output_session_id(encrypted_api_key)\n    session_key = session_data[\"output_SessionID\"]\n\n    # Encrypt the session key for use in transactions\n    {:ok, encrypted_session_key} = ElixirMpesa.GenerateSessionKey.encrypt_session_id(session_key)","ref":"ElixirMpesa.GenerateSessionKey.html#module-example","title":"Example - ElixirMpesa.GenerateSessionKey","type":"module"},{"doc":"Encrypts the API key using the configured public key.\n\nThis function takes the API key and encrypts it using the RSA public key provided by M-Pesa.\nThe encrypted API key is then used to obtain a session key.","ref":"ElixirMpesa.GenerateSessionKey.html#encrypt_api_key/1","title":"ElixirMpesa.GenerateSessionKey.encrypt_api_key/1","type":"function"},{"doc":"* `:public_key` - Override the configured public key\n* `:api_key` - Override the configured API key\n* `:api_type` - Override the configured API type (\"sandbox\" or \"openapi\")\n* `:url_context` - Override the configured URL context","ref":"ElixirMpesa.GenerateSessionKey.html#encrypt_api_key/1-options","title":"Options - ElixirMpesa.GenerateSessionKey.encrypt_api_key/1","type":"function"},{"doc":"* `{:ok, encrypted_api_key}` - The successfully encrypted API key\n* `{:error, reason}` - If encryption fails","ref":"ElixirMpesa.GenerateSessionKey.html#encrypt_api_key/1-returns","title":"Returns - ElixirMpesa.GenerateSessionKey.encrypt_api_key/1","type":"function"},{"doc":"iex> ElixirMpesa.GenerateSessionKey.encrypt_api_key()\n    {:ok, \"encrypted_api_key_string\"}\n\n    iex> ElixirMpesa.GenerateSessionKey.encrypt_api_key([public_key: \"custom_public_key\"])\n    {:ok, \"encrypted_api_key_string\"}","ref":"ElixirMpesa.GenerateSessionKey.html#encrypt_api_key/1-examples","title":"Examples - ElixirMpesa.GenerateSessionKey.encrypt_api_key/1","type":"function"},{"doc":"Encrypts a session ID using the configured public key.\n\nAfter obtaining a session ID from the M-Pesa API, it needs to be encrypted\nbefore it can be used in subsequent API calls.","ref":"ElixirMpesa.GenerateSessionKey.html#encrypt_session_id/2","title":"ElixirMpesa.GenerateSessionKey.encrypt_session_id/2","type":"function"},{"doc":"* `session_id` - The session ID to encrypt\n* `options` - A keyword list of options (see below)","ref":"ElixirMpesa.GenerateSessionKey.html#encrypt_session_id/2-parameters","title":"Parameters - ElixirMpesa.GenerateSessionKey.encrypt_session_id/2","type":"function"},{"doc":"* `:public_key` - Override the configured public key","ref":"ElixirMpesa.GenerateSessionKey.html#encrypt_session_id/2-options","title":"Options - ElixirMpesa.GenerateSessionKey.encrypt_session_id/2","type":"function"},{"doc":"* `{:ok, encrypted_session_id}` - The successfully encrypted session ID\n* `{:error, reason}` - If encryption fails","ref":"ElixirMpesa.GenerateSessionKey.html#encrypt_session_id/2-returns","title":"Returns - ElixirMpesa.GenerateSessionKey.encrypt_session_id/2","type":"function"},{"doc":"iex> ElixirMpesa.GenerateSessionKey.encrypt_session_id(\"session_id_string\")\n    {:ok, \"encrypted_session_id_string\"}","ref":"ElixirMpesa.GenerateSessionKey.html#encrypt_session_id/2-examples","title":"Examples - ElixirMpesa.GenerateSessionKey.encrypt_session_id/2","type":"function"},{"doc":"Generates a session ID by sending the encrypted API key to the M-Pesa API.","ref":"ElixirMpesa.GenerateSessionKey.html#generate_output_session_id/2","title":"ElixirMpesa.GenerateSessionKey.generate_output_session_id/2","type":"function"},{"doc":"* `encrypted_api_key` - The encrypted API key (optional, will use the configured key if nil)\n* `options` - A keyword list of options (see below)","ref":"ElixirMpesa.GenerateSessionKey.html#generate_output_session_id/2-parameters","title":"Parameters - ElixirMpesa.GenerateSessionKey.generate_output_session_id/2","type":"function"},{"doc":"* `:api_type` - Override the configured API type (\"sandbox\" or \"openapi\")\n* `:url_context` - Override the configured URL context","ref":"ElixirMpesa.GenerateSessionKey.html#generate_output_session_id/2-options","title":"Options - ElixirMpesa.GenerateSessionKey.generate_output_session_id/2","type":"function"},{"doc":"* `{:ok, response}` - The API response containing the session ID\n* `{:error, reason}` - If the API call fails","ref":"ElixirMpesa.GenerateSessionKey.html#generate_output_session_id/2-returns","title":"Returns - ElixirMpesa.GenerateSessionKey.generate_output_session_id/2","type":"function"},{"doc":"iex> {:ok, encrypted_key} = ElixirMpesa.GenerateSessionKey.encrypt_api_key()\n    iex> ElixirMpesa.GenerateSessionKey.generate_output_session_id(encrypted_key)\n    {:ok, %{\"output_ResponseCode\" => \"INS-0\", \"output_ResponseDesc\" => \"Request processed successfully\", \"output_SessionID\" => \"session_id_string\"}}","ref":"ElixirMpesa.GenerateSessionKey.html#generate_output_session_id/2-examples","title":"Examples - ElixirMpesa.GenerateSessionKey.generate_output_session_id/2","type":"function"},{"doc":"Handles transaction operations for the M-Pesa OpenAPI.\n\nThis module provides functions for various M-Pesa transaction types, including:\n- Customer to Business (C2B) payments\n- Business to Customer (B2C) payments\n- Business to Business (B2B) payments\n- Transaction status queries\n- Direct debit operations\n- Beneficiary name queries\n\nAll functions require an encrypted session key that must be generated first using\nthe `ElixirMpesa.GenerateSessionKey` module.","ref":"ElixirMpesa.Transactions.html","title":"ElixirMpesa.Transactions","type":"module"},{"doc":"# First, encrypt the API key and get a session key\n    {:ok, encrypted_api_key} = ElixirMpesa.encrypt_api_key()\n    {:ok, session_data} = ElixirMpesa.generate_session_key(encrypted_api_key)\n    session_key = session_data[\"output_SessionID\"]\n    {:ok, encrypted_session_key} = ElixirMpesa.encrypt_session_key(session_key)\n\n    # Then, perform a C2B transaction\n    payment_data = %{\n      \"input_Amount\" => 10.0,\n      \"input_Country\" => \"LES\",\n      \"input_Currency\" => \"LSL\",\n      \"input_CustomerMSISDN\" => \"26675000000\",\n      \"input_ServiceProviderCode\" => \"00000\",\n      \"input_ThirdPartyConversationID\" => \"asv02e5958774f7ba228d83d0d689761\",\n      \"input_TransactionReference\" => \"T12344C\",\n      \"input_PurchasedItemsDesc\" => \"Test purchase\"\n    }\n\n    {:ok, result} = ElixirMpesa.Transactions.c2b_single_stage(payment_data, encrypted_session_key)","ref":"ElixirMpesa.Transactions.html#module-example-usage","title":"Example Usage - ElixirMpesa.Transactions","type":"module"},{"doc":"Performs a Business to Business (B2B) single-stage payment.\n\nThis function allows businesses to pay other businesses.","ref":"ElixirMpesa.Transactions.html#b2b_single_stage/3","title":"ElixirMpesa.Transactions.b2b_single_stage/3","type":"function"},{"doc":"* `attrs` - Map containing the transaction details\n* `encrypt_api_key` - The encrypted session key\n* `options` - A keyword list of options (see below)","ref":"ElixirMpesa.Transactions.html#b2b_single_stage/3-parameters","title":"Parameters - ElixirMpesa.Transactions.b2b_single_stage/3","type":"function"},{"doc":"* `:api_type` - Override the configured API type (\"sandbox\" or \"openapi\")\n* `:url_context` - Override the configured URL context","ref":"ElixirMpesa.Transactions.html#b2b_single_stage/3-options","title":"Options - ElixirMpesa.Transactions.b2b_single_stage/3","type":"function"},{"doc":"* `\"input_Amount\"` - The transaction amount\n* `\"input_Country\"` - The country code (e.g., \"LES\")\n* `\"input_Currency\"` - The currency code (e.g., \"LSL\")\n* `\"input_PrimaryPartyCode\"` - The primary party code (your business)\n* `\"input_ReceiverPartyCode\"` - The receiver party code (recipient business)\n* `\"input_ThirdPartyConversationID\"` - A unique ID for this transaction\n* `\"input_TransactionReference\"` - Your reference for this transaction\n* `\"input_PurchasedItemsDesc\"` - Description of the payment","ref":"ElixirMpesa.Transactions.html#b2b_single_stage/3-required-attributes","title":"Required Attributes - ElixirMpesa.Transactions.b2b_single_stage/3","type":"function"},{"doc":"* `{:ok, response}` - The API response on success\n* `{:error, reason}` - If the API call fails","ref":"ElixirMpesa.Transactions.html#b2b_single_stage/3-returns","title":"Returns - ElixirMpesa.Transactions.b2b_single_stage/3","type":"function"},{"doc":"iex> payment_data = %{\n    ...>   \"input_Amount\" => 1000.0,\n    ...>   \"input_Country\" => \"LES\",\n    ...>   \"input_Currency\" => \"LSL\",\n    ...>   \"input_PrimaryPartyCode\" => \"12345\",\n    ...>   \"input_ReceiverPartyCode\" => \"54321\",\n    ...>   \"input_ThirdPartyConversationID\" => \"asv02e5958774f7ba228d83d0d689761\",\n    ...>   \"input_TransactionReference\" => \"T12344C\",\n    ...>   \"input_PurchasedItemsDesc\" => \"Invoice payment\"\n    ...> }\n    iex> ElixirMpesa.Transactions.b2b_single_stage(payment_data, encrypted_session_key)\n    {:ok, %{\"output_ResponseCode\" => \"INS-0\", \"output_ResponseDesc\" => \"Request processed successfully\", ...}}","ref":"ElixirMpesa.Transactions.html#b2b_single_stage/3-examples","title":"Examples - ElixirMpesa.Transactions.b2b_single_stage/3","type":"function"},{"doc":"Performs a Business to Customer (B2C) single-stage payment.\n\nThis function allows businesses to pay customers, such as for disbursements,\nrefunds, or salary payments.","ref":"ElixirMpesa.Transactions.html#b2c_single_stage/3","title":"ElixirMpesa.Transactions.b2c_single_stage/3","type":"function"},{"doc":"* `attrs` - Map containing the transaction details\n* `encrypt_api_key` - The encrypted session key\n* `options` - A keyword list of options (see below)","ref":"ElixirMpesa.Transactions.html#b2c_single_stage/3-parameters","title":"Parameters - ElixirMpesa.Transactions.b2c_single_stage/3","type":"function"},{"doc":"* `:api_type` - Override the configured API type (\"sandbox\" or \"openapi\")\n* `:url_context` - Override the configured URL context","ref":"ElixirMpesa.Transactions.html#b2c_single_stage/3-options","title":"Options - ElixirMpesa.Transactions.b2c_single_stage/3","type":"function"},{"doc":"* `\"input_Amount\"` - The transaction amount\n* `\"input_Country\"` - The country code (e.g., \"LES\")\n* `\"input_Currency\"` - The currency code (e.g., \"LSL\")\n* `\"input_CustomerMSISDN\"` - The recipient's phone number\n* `\"input_ServiceProviderCode\"` - The service provider code\n* `\"input_ThirdPartyConversationID\"` - A unique ID for this transaction\n* `\"input_TransactionReference\"` - Your reference for this transaction\n* `\"input_PaymentItemsDesc\"` - Description of the payment","ref":"ElixirMpesa.Transactions.html#b2c_single_stage/3-required-attributes","title":"Required Attributes - ElixirMpesa.Transactions.b2c_single_stage/3","type":"function"},{"doc":"* `{:ok, response}` - The API response on success\n* `{:error, reason}` - If the API call fails","ref":"ElixirMpesa.Transactions.html#b2c_single_stage/3-returns","title":"Returns - ElixirMpesa.Transactions.b2c_single_stage/3","type":"function"},{"doc":"iex> payment_data = %{\n    ...>   \"input_Amount\" => 10.0,\n    ...>   \"input_Country\" => \"LES\",\n    ...>   \"input_Currency\" => \"LSL\",\n    ...>   \"input_CustomerMSISDN\" => \"26675000000\",\n    ...>   \"input_ServiceProviderCode\" => \"00000\",\n    ...>   \"input_ThirdPartyConversationID\" => \"asv02e5958774f7ba228d83d0d689761\",\n    ...>   \"input_TransactionReference\" => \"T12344C\",\n    ...>   \"input_PaymentItemsDesc\" => \"Salary payment\"\n    ...> }\n    iex> ElixirMpesa.Transactions.b2c_single_stage(payment_data, encrypted_session_key)\n    {:ok, %{\"output_ResponseCode\" => \"INS-0\", \"output_ResponseDesc\" => \"Request processed successfully\", ...}}","ref":"ElixirMpesa.Transactions.html#b2c_single_stage/3-examples","title":"Examples - ElixirMpesa.Transactions.b2c_single_stage/3","type":"function"},{"doc":"Performs a Customer to Business (C2B) single-stage payment.\n\nThis function allows customers to pay businesses for goods or services.","ref":"ElixirMpesa.Transactions.html#c2b_single_stage/3","title":"ElixirMpesa.Transactions.c2b_single_stage/3","type":"function"},{"doc":"* `attrs` - Map containing the transaction details\n* `encrypt_api_key` - The encrypted session key\n* `options` - A keyword list of options (see below)","ref":"ElixirMpesa.Transactions.html#c2b_single_stage/3-parameters","title":"Parameters - ElixirMpesa.Transactions.c2b_single_stage/3","type":"function"},{"doc":"* `:api_type` - Override the configured API type (\"sandbox\" or \"openapi\")\n* `:url_context` - Override the configured URL context","ref":"ElixirMpesa.Transactions.html#c2b_single_stage/3-options","title":"Options - ElixirMpesa.Transactions.c2b_single_stage/3","type":"function"},{"doc":"* `\"input_Amount\"` - The transaction amount\n* `\"input_Country\"` - The country code (e.g., \"LES\")\n* `\"input_Currency\"` - The currency code (e.g., \"LSL\")\n* `\"input_CustomerMSISDN\"` - The customer's phone number\n* `\"input_ServiceProviderCode\"` - The service provider code\n* `\"input_ThirdPartyConversationID\"` - A unique ID for this transaction\n* `\"input_TransactionReference\"` - Your reference for this transaction\n* `\"input_PurchasedItemsDesc\"` - Description of the purchase","ref":"ElixirMpesa.Transactions.html#c2b_single_stage/3-required-attributes","title":"Required Attributes - ElixirMpesa.Transactions.c2b_single_stage/3","type":"function"},{"doc":"* `{:ok, response}` - The API response on success\n* `{:error, reason}` - If the API call fails","ref":"ElixirMpesa.Transactions.html#c2b_single_stage/3-returns","title":"Returns - ElixirMpesa.Transactions.c2b_single_stage/3","type":"function"},{"doc":"iex> payment_data = %{\n    ...>   \"input_Amount\" => 10.0,\n    ...>   \"input_Country\" => \"LES\",\n    ...>   \"input_Currency\" => \"LSL\",\n    ...>   \"input_CustomerMSISDN\" => \"26675000000\",\n    ...>   \"input_ServiceProviderCode\" => \"00000\",\n    ...>   \"input_ThirdPartyConversationID\" => \"asv02e5958774f7ba228d83d0d689761\",\n    ...>   \"input_TransactionReference\" => \"T12344C\",\n    ...>   \"input_PurchasedItemsDesc\" => \"Test purchase\"\n    ...> }\n    iex> ElixirMpesa.Transactions.c2b_single_stage(payment_data, encrypted_session_key)\n    {:ok, %{\"output_ResponseCode\" => \"INS-0\", \"output_ResponseDesc\" => \"Request processed successfully\", ...}}","ref":"ElixirMpesa.Transactions.html#c2b_single_stage/3-examples","title":"Examples - ElixirMpesa.Transactions.c2b_single_stage/3","type":"function"},{"doc":"Cancels a direct debit mandate.","ref":"ElixirMpesa.Transactions.html#direct_debit_cancel/3","title":"ElixirMpesa.Transactions.direct_debit_cancel/3","type":"function"},{"doc":"* `attrs` - Map containing the cancellation details\n* `encrypt_api_key` - The encrypted session key\n* `options` - A keyword list of options (see below)","ref":"ElixirMpesa.Transactions.html#direct_debit_cancel/3-parameters","title":"Parameters - ElixirMpesa.Transactions.direct_debit_cancel/3","type":"function"},{"doc":"* `:api_type` - Override the configured API type (\"sandbox\" or \"openapi\")\n* `:url_context` - Override the configured URL context","ref":"ElixirMpesa.Transactions.html#direct_debit_cancel/3-options","title":"Options - ElixirMpesa.Transactions.direct_debit_cancel/3","type":"function"},{"doc":"* `\"input_CustomerMSISDN\"` - The customer's phone number\n* `\"input_Country\"` - The country code (e.g., \"LES\")\n* `\"input_ServiceProviderCode\"` - The service provider code\n* `\"input_ThirdPartyConversationID\"` - A unique ID for this cancellation\n* `\"input_ThirdPartyReference\"` - The original mandate reference","ref":"ElixirMpesa.Transactions.html#direct_debit_cancel/3-required-attributes","title":"Required Attributes - ElixirMpesa.Transactions.direct_debit_cancel/3","type":"function"},{"doc":"* `{:ok, response}` - The API response on success\n* `{:error, reason}` - If the API call fails","ref":"ElixirMpesa.Transactions.html#direct_debit_cancel/3-returns","title":"Returns - ElixirMpesa.Transactions.direct_debit_cancel/3","type":"function"},{"doc":"iex> cancel_data = %{\n    ...>   \"input_CustomerMSISDN\" => \"26675000000\",\n    ...>   \"input_Country\" => \"LES\",\n    ...>   \"input_ServiceProviderCode\" => \"00000\",\n    ...>   \"input_ThirdPartyConversationID\" => \"asv02e5958774f7ba228d83d0d689761\",\n    ...>   \"input_ThirdPartyReference\" => \"3333\"\n    ...> }\n    iex> ElixirMpesa.Transactions.direct_debit_cancel(cancel_data, encrypted_session_key)\n    {:ok, %{\"output_ResponseCode\" => \"INS-0\", \"output_ResponseDesc\" => \"Request processed successfully\", ...}}","ref":"ElixirMpesa.Transactions.html#direct_debit_cancel/3-examples","title":"Examples - ElixirMpesa.Transactions.direct_debit_cancel/3","type":"function"},{"doc":"Creates a direct debit mandate.","ref":"ElixirMpesa.Transactions.html#direct_debit_creation/3","title":"ElixirMpesa.Transactions.direct_debit_creation/3","type":"function"},{"doc":"* `attrs` - Map containing the direct debit details\n* `encrypt_api_key` - The encrypted session key\n* `options` - A keyword list of options (see below)","ref":"ElixirMpesa.Transactions.html#direct_debit_creation/3-parameters","title":"Parameters - ElixirMpesa.Transactions.direct_debit_creation/3","type":"function"},{"doc":"* `:api_type` - Override the configured API type (\"sandbox\" or \"openapi\")\n* `:url_context` - Override the configured URL context","ref":"ElixirMpesa.Transactions.html#direct_debit_creation/3-options","title":"Options - ElixirMpesa.Transactions.direct_debit_creation/3","type":"function"},{"doc":"* `\"input_AgreedTC\"` - Whether the customer has agreed to terms and conditions (boolean)\n* `\"input_Country\"` - The country code (e.g., \"LES\")\n* `\"input_CustomerMSISDN\"` - The customer's phone number\n* `\"input_ServiceProviderCode\"` - The service provider code\n* `\"input_ThirdPartyConversationID\"` - A unique ID for this transaction\n* `\"input_ThirdPartyReference\"` - Your reference for this mandate","ref":"ElixirMpesa.Transactions.html#direct_debit_creation/3-required-attributes","title":"Required Attributes - ElixirMpesa.Transactions.direct_debit_creation/3","type":"function"},{"doc":"* `{:ok, response}` - The API response on success\n* `{:error, reason}` - If the API call fails","ref":"ElixirMpesa.Transactions.html#direct_debit_creation/3-returns","title":"Returns - ElixirMpesa.Transactions.direct_debit_creation/3","type":"function"},{"doc":"iex> direct_debit_data = %{\n    ...>   \"input_AgreedTC\" => true,\n    ...>   \"input_Country\" => \"LES\",\n    ...>   \"input_CustomerMSISDN\" => \"26675000000\",\n    ...>   \"input_ServiceProviderCode\" => \"00000\",\n    ...>   \"input_ThirdPartyConversationID\" => \"asv02e5958774f7ba228d83d0d689761\",\n    ...>   \"input_ThirdPartyReference\" => \"3333\"\n    ...> }\n    iex> ElixirMpesa.Transactions.direct_debit_creation(direct_debit_data, encrypted_session_key)\n    {:ok, %{\"output_ResponseCode\" => \"INS-0\", \"output_ResponseDesc\" => \"Request processed successfully\", ...}}","ref":"ElixirMpesa.Transactions.html#direct_debit_creation/3-examples","title":"Examples - ElixirMpesa.Transactions.direct_debit_creation/3","type":"function"},{"doc":"Processes a direct debit payment.","ref":"ElixirMpesa.Transactions.html#direct_debit_payment/3","title":"ElixirMpesa.Transactions.direct_debit_payment/3","type":"function"},{"doc":"* `attrs` - Map containing the payment details\n* `encrypt_api_key` - The encrypted session key\n* `options` - A keyword list of options (see below)","ref":"ElixirMpesa.Transactions.html#direct_debit_payment/3-parameters","title":"Parameters - ElixirMpesa.Transactions.direct_debit_payment/3","type":"function"},{"doc":"* `:api_type` - Override the configured API type (\"sandbox\" or \"openapi\")\n* `:url_context` - Override the configured URL context","ref":"ElixirMpesa.Transactions.html#direct_debit_payment/3-options","title":"Options - ElixirMpesa.Transactions.direct_debit_payment/3","type":"function"},{"doc":"* `\"input_Amount\"` - The transaction amount\n* `\"input_Country\"` - The country code (e.g., \"LES\")\n* `\"input_Currency\"` - The currency code (e.g., \"LSL\")\n* `\"input_CustomerMSISDN\"` - The customer's phone number\n* `\"input_ServiceProviderCode\"` - The service provider code\n* `\"input_ThirdPartyConversationID\"` - A unique ID for this transaction\n* `\"input_ThirdPartyReference\"` - Your reference for this payment","ref":"ElixirMpesa.Transactions.html#direct_debit_payment/3-required-attributes","title":"Required Attributes - ElixirMpesa.Transactions.direct_debit_payment/3","type":"function"},{"doc":"* `{:ok, response}` - The API response on success\n* `{:error, reason}` - If the API call fails","ref":"ElixirMpesa.Transactions.html#direct_debit_payment/3-returns","title":"Returns - ElixirMpesa.Transactions.direct_debit_payment/3","type":"function"},{"doc":"iex> payment_data = %{\n    ...>   \"input_Amount\" => 10.0,\n    ...>   \"input_Country\" => \"LES\",\n    ...>   \"input_Currency\" => \"LSL\",\n    ...>   \"input_CustomerMSISDN\" => \"26675000000\",\n    ...>   \"input_ServiceProviderCode\" => \"00000\",\n    ...>   \"input_ThirdPartyConversationID\" => \"asv02e5958774f7ba228d83d0d689761\",\n    ...>   \"input_ThirdPartyReference\" => \"3333\"\n    ...> }\n    iex> ElixirMpesa.Transactions.direct_debit_payment(payment_data, encrypted_session_key)\n    {:ok, %{\"output_ResponseCode\" => \"INS-0\", \"output_ResponseDesc\" => \"Request processed successfully\", ...}}","ref":"ElixirMpesa.Transactions.html#direct_debit_payment/3-examples","title":"Examples - ElixirMpesa.Transactions.direct_debit_payment/3","type":"function"},{"doc":"Queries a beneficiary's name based on their mobile number.","ref":"ElixirMpesa.Transactions.html#query_beneficiary_name/3","title":"ElixirMpesa.Transactions.query_beneficiary_name/3","type":"function"},{"doc":"* `attrs` - Map containing the query details\n* `encrypt_api_key` - The encrypted session key\n* `options` - A keyword list of options (see below)","ref":"ElixirMpesa.Transactions.html#query_beneficiary_name/3-parameters","title":"Parameters - ElixirMpesa.Transactions.query_beneficiary_name/3","type":"function"},{"doc":"* `:api_type` - Override the configured API type (\"sandbox\" or \"openapi\")\n* `:url_context` - Override the configured URL context","ref":"ElixirMpesa.Transactions.html#query_beneficiary_name/3-options","title":"Options - ElixirMpesa.Transactions.query_beneficiary_name/3","type":"function"},{"doc":"* `\"input_CustomerMSISDN\"` - The customer's phone number\n* `\"input_Country\"` - The country code (e.g., \"LES\")\n* `\"input_ServiceProviderCode\"` - The service provider code\n* `\"input_ThirdPartyConversationID\"` - A unique ID for this query","ref":"ElixirMpesa.Transactions.html#query_beneficiary_name/3-required-attributes","title":"Required Attributes - ElixirMpesa.Transactions.query_beneficiary_name/3","type":"function"},{"doc":"* `{:ok, response}` - The API response on success\n* `{:error, reason}` - If the API call fails","ref":"ElixirMpesa.Transactions.html#query_beneficiary_name/3-returns","title":"Returns - ElixirMpesa.Transactions.query_beneficiary_name/3","type":"function"},{"doc":"iex> query_data = %{\n    ...>   \"input_CustomerMSISDN\" => \"26675000000\",\n    ...>   \"input_Country\" => \"LES\",\n    ...>   \"input_ServiceProviderCode\" => \"00000\",\n    ...>   \"input_ThirdPartyConversationID\" => \"asv02e5958774f7ba228d83d0d689761\"\n    ...> }\n    iex> ElixirMpesa.Transactions.query_beneficiary_name(query_data, encrypted_session_key)\n    {:ok, %{\"output_ResponseCode\" => \"INS-0\", \"output_ResponseDesc\" => \"Request processed successfully\", \"output_CustomerFirstName\" => \"John\", \"output_CustomerLastName\" => \"Doe\"}}","ref":"ElixirMpesa.Transactions.html#query_beneficiary_name/3-examples","title":"Examples - ElixirMpesa.Transactions.query_beneficiary_name/3","type":"function"},{"doc":"Queries the status of a direct debit mandate.","ref":"ElixirMpesa.Transactions.html#query_direct_debit/3","title":"ElixirMpesa.Transactions.query_direct_debit/3","type":"function"},{"doc":"* `attrs` - Map containing the query details\n* `encrypt_api_key` - The encrypted session key\n* `options` - A keyword list of options (see below)","ref":"ElixirMpesa.Transactions.html#query_direct_debit/3-parameters","title":"Parameters - ElixirMpesa.Transactions.query_direct_debit/3","type":"function"},{"doc":"* `:api_type` - Override the configured API type (\"sandbox\" or \"openapi\")\n* `:url_context` - Override the configured URL context","ref":"ElixirMpesa.Transactions.html#query_direct_debit/3-options","title":"Options - ElixirMpesa.Transactions.query_direct_debit/3","type":"function"},{"doc":"* `\"input_CustomerMSISDN\"` - The customer's phone number\n* `\"input_Country\"` - The country code (e.g., \"LES\")\n* `\"input_ServiceProviderCode\"` - The service provider code\n* `\"input_ThirdPartyConversationID\"` - A unique ID for this query\n* `\"input_ThirdPartyReference\"` - The original mandate reference","ref":"ElixirMpesa.Transactions.html#query_direct_debit/3-required-attributes","title":"Required Attributes - ElixirMpesa.Transactions.query_direct_debit/3","type":"function"},{"doc":"* `{:ok, response}` - The API response on success\n* `{:error, reason}` - If the API call fails","ref":"ElixirMpesa.Transactions.html#query_direct_debit/3-returns","title":"Returns - ElixirMpesa.Transactions.query_direct_debit/3","type":"function"},{"doc":"iex> query_data = %{\n    ...>   \"input_CustomerMSISDN\" => \"26675000000\",\n    ...>   \"input_Country\" => \"LES\",\n    ...>   \"input_ServiceProviderCode\" => \"00000\",\n    ...>   \"input_ThirdPartyConversationID\" => \"asv02e5958774f7ba228d83d0d689761\",\n    ...>   \"input_ThirdPartyReference\" => \"3333\"\n    ...> }\n    iex> ElixirMpesa.Transactions.query_direct_debit(query_data, encrypted_session_key)\n    {:ok, %{\"output_ResponseCode\" => \"INS-0\", \"output_ResponseDesc\" => \"Request processed successfully\", ...}}","ref":"ElixirMpesa.Transactions.html#query_direct_debit/3-examples","title":"Examples - ElixirMpesa.Transactions.query_direct_debit/3","type":"function"},{"doc":"Queries the status of a transaction.","ref":"ElixirMpesa.Transactions.html#query_status/3","title":"ElixirMpesa.Transactions.query_status/3","type":"function"},{"doc":"* `attrs` - Map containing the query details\n* `encrypt_api_key` - The encrypted session key\n* `options` - A keyword list of options (see below)","ref":"ElixirMpesa.Transactions.html#query_status/3-parameters","title":"Parameters - ElixirMpesa.Transactions.query_status/3","type":"function"},{"doc":"* `:api_type` - Override the configured API type (\"sandbox\" or \"openapi\")\n* `:url_context` - Override the configured URL context","ref":"ElixirMpesa.Transactions.html#query_status/3-options","title":"Options - ElixirMpesa.Transactions.query_status/3","type":"function"},{"doc":"* `\"input_QueryReference\"` - The original transaction reference\n* `\"input_ServiceProviderCode\"` - The service provider code\n* `\"input_ThirdPartyConversationID\"` - A unique ID for this query\n* `\"input_Country\"` - The country code (e.g., \"LES\")","ref":"ElixirMpesa.Transactions.html#query_status/3-required-attributes","title":"Required Attributes - ElixirMpesa.Transactions.query_status/3","type":"function"},{"doc":"* `{:ok, response}` - The API response on success\n* `{:error, reason}` - If the API call fails","ref":"ElixirMpesa.Transactions.html#query_status/3-returns","title":"Returns - ElixirMpesa.Transactions.query_status/3","type":"function"},{"doc":"iex> query_data = %{\n    ...>   \"input_QueryReference\" => \"T12344C\",\n    ...>   \"input_ServiceProviderCode\" => \"00000\",\n    ...>   \"input_ThirdPartyConversationID\" => \"asv02e5958774f7ba228d83d0d689761\",\n    ...>   \"input_Country\" => \"LES\"\n    ...> }\n    iex> ElixirMpesa.Transactions.query_status(query_data, encrypted_session_key)\n    {:ok, %{\"output_ResponseCode\" => \"INS-0\", \"output_ResponseDesc\" => \"Request processed successfully\", ...}}","ref":"ElixirMpesa.Transactions.html#query_status/3-examples","title":"Examples - ElixirMpesa.Transactions.query_status/3","type":"function"},{"doc":"Reverses a transaction.","ref":"ElixirMpesa.Transactions.html#reversal/3","title":"ElixirMpesa.Transactions.reversal/3","type":"function"},{"doc":"* `attrs` - Map containing the reversal details\n* `encrypt_api_key` - The encrypted session key\n* `options` - A keyword list of options (see below)","ref":"ElixirMpesa.Transactions.html#reversal/3-parameters","title":"Parameters - ElixirMpesa.Transactions.reversal/3","type":"function"},{"doc":"* `:api_type` - Override the configured API type (\"sandbox\" or \"openapi\")\n* `:url_context` - Override the configured URL context","ref":"ElixirMpesa.Transactions.html#reversal/3-options","title":"Options - ElixirMpesa.Transactions.reversal/3","type":"function"},{"doc":"* `\"input_ReversalAmount\"` - The amount to reverse\n* `\"input_Country\"` - The country code (e.g., \"LES\")\n* `\"input_ServiceProviderCode\"` - The service provider code\n* `\"input_ThirdPartyConversationID\"` - A unique ID for this reversal\n* `\"input_TransactionID\"` - The original transaction ID","ref":"ElixirMpesa.Transactions.html#reversal/3-required-attributes","title":"Required Attributes - ElixirMpesa.Transactions.reversal/3","type":"function"},{"doc":"* `{:ok, response}` - The API response on success\n* `{:error, reason}` - If the API call fails","ref":"ElixirMpesa.Transactions.html#reversal/3-returns","title":"Returns - ElixirMpesa.Transactions.reversal/3","type":"function"},{"doc":"iex> reversal_data = %{\n    ...>   \"input_ReversalAmount\" => 10.0,\n    ...>   \"input_Country\" => \"LES\",\n    ...>   \"input_ServiceProviderCode\" => \"00000\",\n    ...>   \"input_ThirdPartyConversationID\" => \"asv02e5958774f7ba228d83d0d689761\",\n    ...>   \"input_TransactionID\" => \"12345678\"\n    ...> }\n    iex> ElixirMpesa.Transactions.reversal(reversal_data, encrypted_session_key)\n    {:ok, %{\"output_ResponseCode\" => \"INS-0\", \"output_ResponseDesc\" => \"Request processed successfully\", ...}}","ref":"ElixirMpesa.Transactions.html#reversal/3-examples","title":"Examples - ElixirMpesa.Transactions.reversal/3","type":"function"},{"doc":"# ElixirMpesa\n\n[![Hex.pm](https://img.shields.io/hexpm/v/elixir_mpesa.svg)](https://hex.pm/packages/elixir_mpesa)\n[![Hex.pm](https://img.shields.io/hexpm/dt/elixir_mpesa.svg)](https://hex.pm/packages/elixir_mpesa)\n[![Hex.pm](https://img.shields.io/hexpm/l/elixir_mpesa.svg)](https://hex.pm/packages/elixir_mpesa)\n\nAn Elixir library for integrating with the Vodacom M-Pesa OpenAPI. This package provides a simple and elegant way to integrate M-Pesa payment services into your Elixir applications.","ref":"readme.html","title":"ElixirMpesa","type":"extras"},{"doc":"- Session key generation and management\n- Customer to Business (C2B) payments\n- Business to Customer (B2C) payments\n- Business to Business (B2B) payments\n- Transaction status queries\n- Direct debit operations\n- Beneficiary name queries","ref":"readme.html#features","title":"Features - ElixirMpesa","type":"extras"},{"doc":"Add `elixir_mpesa` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:elixir_mpesa, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - ElixirMpesa","type":"extras"},{"doc":"Add the following configuration to your `config/config.exs` file:\n\n```elixir\nconfig :elixir_mpesa,\n  api_type: \"sandbox\", # or \"openapi\" for production\n  input_currency: \"LSL\", # Currency code (e.g., \"LSL\" for Lesotho Loti)\n  input_country: \"LES\", # Country code\n  url_context: \"vodacomLES\", # API context (country-specific)\n  api_key: \"your_api_key_here\", # Your M-Pesa API key\n  public_key: \"your_public_key_here\" # Your M-Pesa public key\n```","ref":"readme.html#configuration","title":"Configuration - ElixirMpesa","type":"extras"},{"doc":"","ref":"readme.html#usage","title":"Usage - ElixirMpesa","type":"extras"},{"doc":"Before making any transaction requests, you need to generate a session key:\n\n```elixir\n# Encrypt your API key\n{:ok, encrypted_api_key} = ElixirMpesa.encrypt_api_key()\n\n# Generate a session key\n{:ok, session_data} = ElixirMpesa.generate_session_key(encrypted_api_key)\nsession_key = session_data[\"output_SessionID\"]\n\n# Encrypt the session key for use in subsequent requests\n{:ok, encrypted_session_key} = ElixirMpesa.encrypt_session_key(session_key)\n```","ref":"readme.html#session-management","title":"Session Management - ElixirMpesa","type":"extras"},{"doc":"```elixir\npayment_data = %{\n  \"input_Amount\" => 10.0,\n  \"input_Country\" => \"LES\",\n  \"input_Currency\" => \"LSL\",\n  \"input_CustomerMSISDN\" => \"26675000000\", # Customer phone number\n  \"input_ServiceProviderCode\" => \"00000\", # Your M-Pesa service provider code\n  \"input_ThirdPartyConversationID\" => \"asv02e5958774f7ba228d83d0d689761\", # Unique transaction ID\n  \"input_TransactionReference\" => \"T12344C\", # Your transaction reference\n  \"input_PurchasedItemsDesc\" => \"Test purchase\" # Description\n}\n\n{:ok, result} = ElixirMpesa.c2b_single_stage(payment_data, encrypted_session_key)\n```","ref":"readme.html#customer-to-business-c2b-payment","title":"Customer to Business (C2B) Payment - ElixirMpesa","type":"extras"},{"doc":"```elixir\npayment_data = %{\n  \"input_Amount\" => 10.0,\n  \"input_Country\" => \"LES\",\n  \"input_Currency\" => \"LSL\",\n  \"input_CustomerMSISDN\" => \"26675000000\", # Recipient phone number\n  \"input_ServiceProviderCode\" => \"00000\", # Your M-Pesa service provider code\n  \"input_ThirdPartyConversationID\" => \"asv02e5958774f7ba228d83d0d689761\", # Unique transaction ID\n  \"input_TransactionReference\" => \"T12344C\", # Your transaction reference\n  \"input_PaymentItemsDesc\" => \"Salary payment\" # Description\n}\n\n{:ok, result} = ElixirMpesa.b2c_single_stage(payment_data, encrypted_session_key)\n```","ref":"readme.html#business-to-customer-b2c-payment","title":"Business to Customer (B2C) Payment - ElixirMpesa","type":"extras"},{"doc":"```elixir\nquery_data = %{\n  \"input_QueryReference\" => \"T12344C\", # Your original transaction reference\n  \"input_ServiceProviderCode\" => \"00000\", # Your M-Pesa service provider code\n  \"input_ThirdPartyConversationID\" => \"asv02e5958774f7ba228d83d0d689761\", # Unique conversation ID\n  \"input_Country\" => \"LES\"\n}\n\n{:ok, result} = ElixirMpesa.query_transaction_status(query_data, encrypted_session_key)\n```","ref":"readme.html#query-transaction-status","title":"Query Transaction Status - ElixirMpesa","type":"extras"},{"doc":"#### Create Direct Debit\n\n```elixir\ndirect_debit_data = %{\n  \"input_AgreedTC\" => true,\n  \"input_Country\" => \"LES\",\n  \"input_CustomerMSISDN\" => \"26675000000\", # Customer phone number\n  \"input_ServiceProviderCode\" => \"00000\", # Your M-Pesa service provider code\n  \"input_ThirdPartyConversationID\" => \"asv02e5958774f7ba228d83d0d689761\", # Unique conversation ID\n  \"input_ThirdPartyReference\" => \"3333\" # Your reference\n}\n\n{:ok, result} = ElixirMpesa.direct_debit_creation(direct_debit_data, encrypted_session_key)\n```\n\n#### Process Direct Debit Payment\n\n```elixir\npayment_data = %{\n  \"input_Amount\" => 10.0,\n  \"input_Country\" => \"LES\",\n  \"input_Currency\" => \"LSL\",\n  \"input_CustomerMSISDN\" => \"26675000000\", # Customer phone number\n  \"input_ServiceProviderCode\" => \"00000\", # Your M-Pesa service provider code\n  \"input_ThirdPartyConversationID\" => \"asv02e5958774f7ba228d83d0d689761\", # Unique conversation ID\n  \"input_ThirdPartyReference\" => \"3333\" # Your reference\n}\n\n{:ok, result} = ElixirMpesa.direct_debit_payment(payment_data, encrypted_session_key)\n```","ref":"readme.html#direct-debit-operations","title":"Direct Debit Operations - ElixirMpesa","type":"extras"},{"doc":"All functions return tagged tuples in the format `{:ok, result}` or `{:error, reason}`:\n\n```elixir\ncase ElixirMpesa.c2b_single_stage(payment_data, encrypted_session_key) do\n  {:ok, result} ->\n    # Handle successful transaction\n    IO.inspect(result)\n  \n  {:error, reason} ->\n    # Handle error\n    IO.inspect(reason)\nend\n```","ref":"readme.html#error-handling","title":"Error Handling - ElixirMpesa","type":"extras"},{"doc":"","ref":"readme.html#advanced-usage","title":"Advanced Usage - ElixirMpesa","type":"extras"},{"doc":"All functions accept an optional keyword list of options that can override the default configuration:\n\n```elixir\n# Override default configuration for a single request\nElixirMpesa.c2b_single_stage(\n  payment_data, \n  encrypted_session_key, \n  [api_type: \"openapi\", url_context: \"vodacomTZN\"]\n)\n```","ref":"readme.html#passing-custom-options","title":"Passing Custom Options - ElixirMpesa","type":"extras"},{"doc":"1. Fork it\n2. Create your feature branch (`git checkout -b feature/my-new-feature`)\n3. Commit your changes (`git commit -am 'Add some feature'`)\n4. Push to the branch (`git push origin feature/my-new-feature`)\n5. Create new Pull Request","ref":"readme.html#contributing","title":"Contributing - ElixirMpesa","type":"extras"},{"doc":"This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.","ref":"readme.html#license","title":"License - ElixirMpesa","type":"extras"},{"doc":"MIT License\n\nCopyright (c) 2025 James Njovu\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html","title":"LICENSE","type":"extras"}],"producer":{"name":"ex_doc","version":"0.37.3"},"proglang":"elixir"}